#

##

###

###

###

    	sanique

    		sanic inspect reload

    	objectives

    		tethered
    			sanique = build_sanique ({
    				"tethered": "yes"
    			})
    			sanique ["on"] ()
    			sanique ["off"] ()

    		floating
    			apoplast organisms sanique on \
    				--garage-port 40303 \
    				--inspector-port 90302

    			apoplast organisms sanique off --inspector-port 90302

    			apoplast organisms sanique status --inspector-port 90302

    		restart on code change
    			https://github.com/gorakhargosh/watchdog